@@ -80,7 +80,7 @@ class TestPep8(unittest.TestCase):
                             'You should define some packages to check')
         for package in self.packages:
             self.pep8style.input_dir(os.path.dirname(package.__file__))
-        self.assertEqual(0, self.pep8style.options.report.total_errors,
+        self.assertEqual([], self.report._msgs,
                          '\n'.join(self.report._msgs))
 
 
