@@ -83,7 +83,7 @@ def set_uniq_path(test):
         {'PATH': os.pathsep.join([test.bin1_dir, test.bin2_dir])})
 
 
-def make_file(path, content, chmod_bits=0644):
+def make_file(path, content, chmod_bits=0o644):
     with open(path, 'w') as f:
         f.write(content)
     os.chmod(path, chmod_bits)
@@ -107,14 +107,14 @@ class TestFindExecutable(unittest.TestCase):
 
     def test_executable(self):
         doit_path = os.path.join(self.bin1_dir, 'doit')
-        make_file(doit_path, 'whatever', 0755)
+        make_file(doit_path, 'whatever', 0o755)
         self.assertEqual(doit_path, spawn.find_executable('doit'))
 
     def test_non_executable_not_ignored(self):
         path1 = os.path.join(self.bin1_dir, 'doit')
         make_file(path1, 'whatever')
         path2 = os.path.join(self.bin2_dir, 'doit')
-        make_file(path2, 'whatever', 0755)
+        make_file(path2, 'whatever', 0o755)
         # Despite 'whatever' not having the 'x' chmod bit it ends up being
         # selected.
         self.assertEqual(path1, spawn.find_executable('doit'))
@@ -133,7 +133,7 @@ class TestExecutableFeature(unittest.TestCase):
     def test_feature_available(self):
         feature = features.ExecutableFeature('doit')
         doit_path = os.path.join(self.bin1_dir, 'doit')
-        make_file(doit_path, 'whatever', 0755)
+        make_file(doit_path, 'whatever', 0o755)
         self.assertTrue(feature.available())
 
 
